@@ -246,31 +246,31 @@ vmod_remove(VRT_CTX, VCL_HEADER hdr, VCL_REGEX re)
 static void
 http_VSLH(const struct http *hp, unsigned hdr)
 {
-        int i;
+	int i;
 
-        if (hp->vsl != NULL) {
-                AN(hp->vsl->wid & (VSL_CLIENTMARKER|VSL_BACKENDMARKER));
-                i = hdr;
-                if (i > HTTP_HDR_FIRST)
-                        i = HTTP_HDR_FIRST;
-                i += hp->logtag;
-                VSLbt(hp->vsl, (enum VSL_tag_e)i, hp->hd[hdr]);
-        }
+	if (hp->vsl != NULL) {
+		assert(VXID_TAG(hp->vsl->wid));
+		i = hdr;
+		if (i > HTTP_HDR_FIRST)
+			i = HTTP_HDR_FIRST;
+		i += hp->logtag;
+		VSLbt(hp->vsl, (enum VSL_tag_e)i, hp->hd[hdr]);
+	}
 }
 
 static void
 http_VSLH_del(const struct http *hp, unsigned hdr)
 {
-        int i;
+	int i;
 
-        if (hp->vsl != NULL) {
-                /* We don't support unsetting stuff in the first line */
-                assert (hdr >= HTTP_HDR_FIRST);
-                AN(hp->vsl->wid & (VSL_CLIENTMARKER|VSL_BACKENDMARKER));
-                i = (HTTP_HDR_UNSET - HTTP_HDR_METHOD);
-                i += hp->logtag;
-                VSLbt(hp->vsl, (enum VSL_tag_e)i, hp->hd[hdr]);
-        }
+	if (hp->vsl != NULL) {
+		/* We don't support unsetting stuff in the first line */
+		assert (hdr >= HTTP_HDR_FIRST);
+		assert(VXID_TAG(hp->vsl->wid));
+		i = (HTTP_HDR_UNSET - HTTP_HDR_METHOD);
+		i += hp->logtag;
+		VSLbt(hp->vsl, (enum VSL_tag_e)i, hp->hd[hdr]);
+	}
 }
 
 VCL_VOID
